# Copyright REFITT Team 2019. All rights reserved.
#
# This program is free software: you can redistribute it and/or modify it under the
# terms of the Apache License (v2.0) as published by the Apache Software Foundation.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the Apache License for more details.
#
# You should have received a copy of the Apache License along with this program.
# If not, see <https://www.apache.org/licenses/LICENSE-2.0>.

"""Package metadata for refitt."""


__appname__     = 'refitt'
__version__     = '0.12.2'
__authors__     = ['Dan Milisavljevic, Ph.D. <dmilisav@purdue.edu>',
                   'Niharika Sravan, Ph.D. <nsravan@purdue.edu>',
                   'Geoffrey Lentner, M.Sc. <glentner@purdue.edu>',
                   'Mark Linvill <mlinvill@purdue.edu>']
__developer__   = 'Geoffrey Lentner'
__contact__     = 'glentner@purdue.edu'
__license__     = 'Apache License 2.0'
__website__     = 'https://github.com/refitt/refitt'
__copyright__   = 'REFITT Team 2019'
__description__ = 'The Recommender Engine for Intelligent Transient Tracking.'
__keywords__    = 'astronomy science machine-learning recommendation service'
__ascii_art__   = r"""
    ____  ____________________________
   / __ \/ ____/ ____/  _/_  __/_  __/
  / /_/ / __/ / /_   / /  / /   / /
 / _, _/ /___/ __/ _/ /  / /   / /
/_/ |_/_____/_/   /___/ /_/   /_/
"""
